<?php

/**
 * MonsterInsights PPC Tracking Google Provider class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ad_Providers
 * @author  David Paternina
 */
class MonsterInsights_PPC_Tracking_Google extends MonsterInsights_PPC_Tracking_Provider {

    /**
     * Google Ads conversion id
     *
     * @var string
     */
    private $conversion_id;

    /**
     * Google Ads conversion label
     *
     * @var string
     */
    private $conversion_label;

    public function __construct() {
        parent::__construct();

        $this->conversion_id = $this->get_conversion_id();
        $this->conversion_label = $this->get_conversion_label();
    }

    /**
     * @inheritDoc
     */
    public function get_provider_id() {
        return 'google';
    }

    /**
     * @inheritDoc
     */
    protected function add_frontend_hooks() {
        add_action( 'monsterinsights_frontend_tracking_gtag_after_pageview', array( $this, 'add_conversion_id_to_gtag_tracking' ) );
    }

    /**
     * @return void
     */
    public function add_conversion_id_to_gtag_tracking() {
        $aw_id = $this->conversion_id;

        if ( ! empty( $aw_id ) ) {
            echo "__gtagTracker( 'config', '" . $aw_id . "' );";
        }
    }

    /**
     * @inheritDoc
     */
    public function maybe_print_conversion_code($conversion_data) {
        if ( empty( $this->conversion_id ) || empty( $this->conversion_label ) ) {
            return false;
        }

        $conversion_data['send_to'] = $this->get_conversion_id_and_label();

        // wp_json_encode not used due to supported WP version.
        echo stripslashes( "\n__gtagTracker( 'event', 'conversion', " . json_encode( $conversion_data ) . " );\n" );
        return true;
    }

    /**
     * Get concatenated conversion id and label
     *
     * @return string
     */
    private function get_conversion_id_and_label() {
        return $this->conversion_id . '/' . $this->conversion_label;
    }

    /**
     * Get conversion id from settings
     *
     * @return string
     */
    private function get_conversion_id() {
        $conversion_id = monsterinsights_get_option( 'ads_google_conversion_id' );
        return apply_filters( 'MonsterInsights_PPC_Tracking_google_conversion_id', $conversion_id );
    }

    /**
     * Get conversion label from settings
     *
     * @return string
     */
    private function get_conversion_label() {
        return apply_filters( 'MonsterInsights_PPC_Tracking_google_label_id', monsterinsights_get_option( 'ads_google_conversion_label' ) );
    }

    /**
     * @inheritdoc
     */
    public function is_active() {
        $is_active = !empty( $this->get_conversion_id() ) && !empty( $this->get_conversion_label() );

        return apply_filters(
            "MonsterInsights_PPC_Tracking_provider_active_{$this->get_provider_id()}",
            $is_active
        );
    }
}
