<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * MonsterInsights PPC Tracking - EDD tracking class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ecommerce_Providers
 * @author  David Paternina
 */

class MonsterInsights_PPC_Tracking_Ecommerce_EDD extends MonsterInsights_PPC_Tracking_Ecommerce_Tracking
{
    /**
     * EDD Payment/order
     *
     * @var $payment EDD_Payment
     */
    protected $payment;

    /**
     * @inheritdoc
     */
    public function do_conversion_checks() {

        $confirmation_page = edd_get_option( 'confirmation_page', false );

        /*
         * AKA "Receipt Page"
         */
        $success_page = edd_get_option( 'success_page', false );

        $possible_pages = [$confirmation_page, $success_page];

        return is_page( $possible_pages );
    }

    /**
     * @inheritdoc
     */
    public function is_active() {
        return class_exists( 'Easy_Digital_Downloads' ) && apply_filters( 'MonsterInsights_PPC_Tracking_track_conversion_edd', true );
    }

    /**
     * @inheritdoc
     */
    public function try_to_get_order() {

        $session = edd_get_purchase_session();

        if ( empty( $session['purchase_key'] ) ) {
            return false;
        }

        $payment_key = $session['purchase_key'];
        $payment_id    = edd_get_purchase_id_by_key( $payment_key );

        if ( empty( $payment_id ) ) {
            return false;
        }

        $this->payment = edd_get_payment( $payment_id );

        return true;
    }

    /**
     * @inheritDoc
     */
    function get_order_total() {
        return empty( $this->payment ) ? null : edd_get_payment_amount( $this->get_order_number() );
    }

    /**
     * @inheritDoc
     */
    function get_order_currency() {
        return empty( $this->payment ) ? null : edd_get_payment_currency_code( $this->get_order_number() );
    }

    /**
     * @inheritDoc
     */
    function get_order_number() {
        return empty( $this->payment ) ? null : $this->payment->ID;
    }

    /**
     * @inheritDoc
     */
    function already_tracked( $provider_id ) {
        if ( empty( $this->payment ) ) {
            return true;
        }

        $tracked = $this->payment->get_meta( "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}", true );

        return ! empty( $tracked ) && 'yes' === $tracked;
    }

    /**
     * @inheritDoc
     */
    function mark_order_tracked( $provider_id ) {
        if ( empty( $this->payment ) ) {
            return;
        }
        $this->payment->update_meta("_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}", 'yes' );
    }

    /**
     * @inheritdoc
     */
    public function get_name()
    {
        return 'EDD';
    }
}
